<?php

add_action( 'admin_init', 'theme_options_init' );
add_action( 'admin_menu', 'theme_options_add_page' );

/**
 * Init plugin options to white list our options
 */
function theme_options_init(){
	register_setting( 'cover_wp_options', 'cover_wp_fp_layout' );
	register_setting( 'cover_wp_options', 'cover_wp_features' );
	register_setting( 'cover_wp_options', 'cover_wp_featured_cat' );
	register_setting( 'cover_wp_options', 'cover_wp_popular' );
}

/**
 * Load up the menu page
 */
function theme_options_add_page() {
	add_theme_page( __( 'Theme Options', 'cover-wp' ), __( 'Theme Options', 'cover-wp' ), 'edit_theme_options', 'theme_options', 'theme_options_do_page' );
}

/**
 * Create arrays for our select and radio options
 */
$radio_options = array(
	'magazine' => array(
		'value' => 'magazine',
		'label' => __( 'Magazine Style', 'cover-wp' )
	),
	'blog' => array(
		'value' => 'blog',
		'label' => __( 'Blog Style', 'cover-wp' )
	)
);

$select_options = array(
	'0' => array(
		'value' =>	'Featured',
		'label' => 'Featured'
	)
);

$categories = get_categories(); $i = 1;

foreach ($categories as $category) {
	if ($category->cat_name != 'Featured') {
		$select_options[$i] = array(
			'value' => $category->cat_name,
			'label' => $category->cat_name
		);
		$i++;
	}
}

$popular = array(
	'comments' => array(
		'value' => 'comments',
		'label' => __( 'Most commented', 'cover-wp' )
	),
	'views' => array(
		'value' => 'views',
		'label' => __( 'Most viewed', 'cover-wp' )
	)
);

/**
 * Create the options page
 */
function theme_options_do_page() {
	global $select_options, $radio_options, $popular;

	if ( ! isset( $_REQUEST['updated'] ) )
		$_REQUEST['updated'] = false;

	?>
	<div class="wrap">
		<?php screen_icon(); echo "<h2>" . get_current_theme() . __( ' Theme Options', 'cover-wp' ) . "</h2>"; ?>

		<?php if ( false !== $_REQUEST['updated'] ) : ?>
		<div class="updated fade"><p><strong><?php _e( 'Options saved', 'cover-wp' ); ?></strong></p></div>
		<?php endif; ?>

		<form method="post" action="options.php">
			<?php settings_fields( 'cover_wp_options' ); ?>

			<table class="form-table">

				<?php
				/**
				 * A cover_wp of radio buttons
				 */
				?>
				<?php $fp_layout = get_option( 'cover_wp_fp_layout', 'magazine' ); ?>
				<tr valign="top"><th scope="row"><?php _e( 'Front Page Layout', 'cover-wp' ); ?></th>
					<td>
						<fieldset><legend class="screen-reader-text"><span><?php _e( 'Front Page Layout', 'cover-wp' ); ?></span></legend>
						<?php
							if ( ! isset( $checked ) )
								$checked = '';
							foreach ( $radio_options as $option ) {
								$radio_setting = $fp_layout;

								if ( '' != $radio_setting ) {
									if ( $fp_layout == $option['value'] ) {
										$checked = "checked=\"checked\"";
									} else {
										$checked = '';
									}
								}
								?>
								<label class="description"><input type="radio" name="cover_wp_fp_layout" value="<?php esc_attr_e( $option['value'] ); ?>" <?php echo $checked; ?> /> <?php echo $option['label']; ?></label><br />
								<?php
							}
						?>
						</fieldset>
					</td>
				</tr>

				<?php
				/**
				 * A cover_wp checkbox option
				 */
				?>
                <?php $features = get_option( 'cover_wp_features', array('social' => 1, 'author' => 1) ); ?>
				<tr valign="top"><th scope="row"><?php _e( 'Features', 'cover-wp' ); ?></th>
					<td>
						<input id="cover_wp_features[social]" name="cover_wp_features[social]" type="checkbox" value="1" <?php checked( 1, $features['social'] ); ?> />
						<label class="description" for="cover_wp_features[social]"><?php _e( 'Show Social Bookmark Icons', 'cover-wp' ); ?></label><br />
						<input id="cover_wp_features[author]" name="cover_wp_features[author]" type="checkbox" value="1" <?php checked( 1, $features['author'] ); ?> />
						<label class="description" for="cover_wp_features[author]"><?php _e( 'Show Author Highlight Box', 'cover-wp' ); ?></label><br />
					</td>
				</tr>

				<?php
				/**
				 * A cover_wp select input option
				 */
				?>
                <?php $featured_cat = get_option( 'cover_wp_featured_cat', 'Featured' ); ?>
				<tr valign="top"><th scope="row"><?php _e( 'Default Featured Category', 'cover-wp' ); ?></th>
					<td>
						<select name="cover_wp_featured_cat" id="cover_wp_featured_cat">
							<?php
								$selected = $featured_cat;
								$p = '';
								$r = '';

								foreach ( $select_options as $option ) {
									$label = $option['label'];
									if ( $selected == $option['value'] ) // Make default first in list
										$p = "\n\t<option style=\"padding-right: 10px;\" selected='selected' value='" . esc_attr( $option['value'] ) . "'>$label</option>";
									else
										$r .= "\n\t<option style=\"padding-right: 10px;\" value='" . esc_attr( $option['value'] ) . "'>$label</option>";
								}
								echo $p . $r;
							?>
						</select>
						<label class="description" for="cover_wp_featured_cat"><?php _e( 'Select Category to display in the Featured Section', 'cover-wp' ); ?></label>
					</td>
				</tr>

				<?php
				/**
				 * A cover_wp of radio buttons
				 */
				?>
				<?php $popular_sec = get_option( 'cover_wp_popular', 'comments' ); ?>
				<tr valign="top"><th scope="row"><?php _e( 'Default Popular View', 'cover-wp' ); ?></th>
					<td>
						<fieldset><legend class="screen-reader-text"><span><?php _e( 'Default Popular View', 'cover-wp' ); ?></span></legend>
						<?php
							if ( ! isset( $checked ) )
								$checked = '';
							foreach ( $popular as $option ) {
								$popular_setting = $popular_sec;

								if ( '' != $popular_setting ) {
									if ( $popular_sec == $option['value'] ) {
										$checked = "checked=\"checked\"";
									} else {
										$checked = '';
									}
								}
								?>
								<label class="description"><input type="radio" name="cover_wp_popular" value="<?php esc_attr_e( $option['value'] ); ?>" <?php echo $checked; ?> /> <?php echo $option['label']; ?></label><br />
								<?php
							}
						?>
						</fieldset>
					</td>
				</tr>
			</table>

			<p class="submit">
				<input type="submit" class="button-primary" value="<?php _e( 'Save Options', 'cover-wp' ); ?>" />
			</p>
		</form>
	</div>
	<?php
}

// adapted from http://planetozh.com/blog/2009/05/handling-plugins-options-in-wordpress-28-with-register_setting/